@@ -23,6 +23,8 @@ from .bittrex import Bittrex
 from .blockchain import Blockchain
 from .bybit import Bybit
 from .coinbase import Coinbase
+from .cryptodotcom import CryptoDotCom
+from .delta import Delta
 from .deribit import Deribit
 from .dydx import dYdX
 from .exx import EXX
@@ -61,7 +63,9 @@ EXCHANGE_MAP = {
     BLOCKCHAIN: Blockchain,
     BYBIT: Bybit,
     COINBASE: Coinbase,
+    CRYPTODOTCOM: CryptoDotCom,
     DERIBIT: Deribit,
+    DELTA: Delta,
     DYDX: dYdX,
     EXX_str: EXX,
     FTX_str: FTX,
