@@ -25,6 +25,7 @@ LOG = logging.getLogger('feedhandler')
 class AscendEX(Feed):
     id = ASCENDEX
     symbol_endpoint = 'https://ascendex.com/api/pro/v1/products'
+    websocket_endpoint = 'wss://ascendex.com/1/api/pro/v1/stream'
     websocket_channels = {
         L2_BOOK: 'depth:',
         TRADES: 'trades:',
@@ -49,10 +50,6 @@ class AscendEX(Feed):
 
         return ret, info
 
-    def __init__(self, **kwargs):
-        super().__init__('wss://ascendex.com/1/api/pro/v1/stream', **kwargs)
-        self.__reset()
-
     def __reset(self):
         self._l2_book = {}
         self.seq_no = defaultdict(lambda: None)
