@@ -21,6 +21,7 @@ LOG = logging.getLogger('feedhandler')
 class BinanceDelivery(Binance, BinanceDeliveryRestMixin):
     id = BINANCE_DELIVERY
     symbol_endpoint = 'https://dapi.binance.com/dapi/v1/exchangeInfo'
+    websocket_endpoint = 'wss://dstream.binance.com'
     listen_key_endpoint = 'listenKey'
     valid_depths = [5, 10, 20, 50, 100, 500, 1000]
     valid_depth_intervals = {'100ms', '250ms', '500ms'}
@@ -35,7 +36,6 @@ class BinanceDelivery(Binance, BinanceDeliveryRestMixin):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         # overwrite values previously set by the super class Binance
-        self.ws_endpoint = 'wss://dstream.binance.com'
         self.rest_endpoint = 'https://dapi.binance.com/dapi/v1'
         self.address = self._address()
         self.ws_defaults['compression'] = None
@@ -125,6 +125,7 @@ class BinanceDelivery(Binance, BinanceDeliveryRestMixin):
                 self.exchange_symbol_to_std_symbol(position['s']),
                 Decimal(position['pa']),
                 Decimal(position['ep']),
+                position['ps'].lower(),
                 Decimal(position['up']),
                 self.timestamp_normalize(msg['E']),
                 raw=msg)
