@@ -6,7 +6,7 @@ associated with this software.
 '''
 import logging
 
-from cryptofeed.defines import FTX_US, L2_BOOK, ORDER_INFO, TICKER, TRADES, USER_FILLS
+from cryptofeed.defines import FTX_US, L2_BOOK, ORDER_INFO, TICKER, TRADES, FILLS
 from cryptofeed.exchanges.ftx import FTX
 from cryptofeed.exchanges.mixins.ftx_rest_us import FTXUSRestMixin
 
@@ -17,14 +17,11 @@ LOG = logging.getLogger('feedhandler')
 class FTXUS(FTX, FTXUSRestMixin):
     id = FTX_US
     symbol_endpoint = 'https://ftx.us/api/markets'
+    websocket_endpoint = 'wss://ftx.us/ws/'
     websocket_channels = {
         L2_BOOK: 'orderbook',
         TRADES: 'trades',
         TICKER: 'ticker',
         ORDER_INFO: 'orders',
-        USER_FILLS: 'fills',
+        FILLS: 'fills',
     }
-
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        self.address = 'wss://ftx.us/ws/'
